@@ -64,6 +64,11 @@ return array (
             'https' => true,
             'hostname' => 'monitoring.sa-east-1.amazonaws.com',
         ),
+        'cn-north-1' => array(
+            'http' => true,
+            'https' => true,
+            'hostname' => 'monitoring.cn-north-1.amazonaws.com.cn',
+        ),
         'us-gov-west-1' => array(
             'http' => false,
             'https' => true,
@@ -135,11 +140,6 @@ return array (
                 'HistoryItemType' => array(
                     'type' => 'string',
                     'location' => 'aws.query',
-                    'enum' => array(
-                        'ConfigurationUpdate',
-                        'StateUpdate',
-                        'Action',
-                    ),
                 ),
                 'StartDate' => array(
                     'type' => array(
@@ -215,11 +215,6 @@ return array (
                 'StateValue' => array(
                     'type' => 'string',
                     'location' => 'aws.query',
-                    'enum' => array(
-                        'OK',
-                        'ALARM',
-                        'INSUFFICIENT_DATA',
-                    ),
                 ),
                 'ActionPrefix' => array(
                     'type' => 'string',
@@ -279,13 +274,6 @@ return array (
                 'Statistic' => array(
                     'type' => 'string',
                     'location' => 'aws.query',
-                    'enum' => array(
-                        'SampleCount',
-                        'Average',
-                        'Sum',
-                        'Minimum',
-                        'Maximum',
-                    ),
                 ),
                 'Dimensions' => array(
                     'type' => 'array',
@@ -319,35 +307,6 @@ return array (
                 'Unit' => array(
                     'type' => 'string',
                     'location' => 'aws.query',
-                    'enum' => array(
-                        'Seconds',
-                        'Microseconds',
-                        'Milliseconds',
-                        'Bytes',
-                        'Kilobytes',
-                        'Megabytes',
-                        'Gigabytes',
-                        'Terabytes',
-                        'Bits',
-                        'Kilobits',
-                        'Megabits',
-                        'Gigabits',
-                        'Terabits',
-                        'Percent',
-                        'Count',
-                        'Bytes/Second',
-                        'Kilobytes/Second',
-                        'Megabytes/Second',
-                        'Gigabytes/Second',
-                        'Terabytes/Second',
-                        'Bits/Second',
-                        'Kilobits/Second',
-                        'Megabits/Second',
-                        'Gigabits/Second',
-                        'Terabits/Second',
-                        'Count/Second',
-                        'None',
-                    ),
                 ),
             ),
         ),
@@ -506,47 +465,11 @@ return array (
                     'items' => array(
                         'name' => 'Statistic',
                         'type' => 'string',
-                        'enum' => array(
-                            'SampleCount',
-                            'Average',
-                            'Sum',
-                            'Minimum',
-                            'Maximum',
-                        ),
                     ),
                 ),
                 'Unit' => array(
                     'type' => 'string',
                     'location' => 'aws.query',
-                    'enum' => array(
-                        'Seconds',
-                        'Microseconds',
-                        'Milliseconds',
-                        'Bytes',
-                        'Kilobytes',
-                        'Megabytes',
-                        'Gigabytes',
-                        'Terabytes',
-                        'Bits',
-                        'Kilobits',
-                        'Megabits',
-                        'Gigabits',
-                        'Terabits',
-                        'Percent',
-                        'Count',
-                        'Bytes/Second',
-                        'Kilobytes/Second',
-                        'Megabytes/Second',
-                        'Gigabytes/Second',
-                        'Terabytes/Second',
-                        'Bits/Second',
-                        'Kilobits/Second',
-                        'Megabits/Second',
-                        'Gigabits/Second',
-                        'Terabits/Second',
-                        'Count/Second',
-                        'None',
-                    ),
                 ),
             ),
             'errorResponses' => array(
@@ -724,13 +647,6 @@ return array (
                     'required' => true,
                     'type' => 'string',
                     'location' => 'aws.query',
-                    'enum' => array(
-                        'SampleCount',
-                        'Average',
-                        'Sum',
-                        'Minimum',
-                        'Maximum',
-                    ),
                 ),
                 'Dimensions' => array(
                     'type' => 'array',
@@ -765,35 +681,6 @@ return array (
                 'Unit' => array(
                     'type' => 'string',
                     'location' => 'aws.query',
-                    'enum' => array(
-                        'Seconds',
-                        'Microseconds',
-                        'Milliseconds',
-                        'Bytes',
-                        'Kilobytes',
-                        'Megabytes',
-                        'Gigabytes',
-                        'Terabytes',
-                        'Bits',
-                        'Kilobits',
-                        'Megabits',
-                        'Gigabits',
-                        'Terabits',
-                        'Percent',
-                        'Count',
-                        'Bytes/Second',
-                        'Kilobytes/Second',
-                        'Megabytes/Second',
-                        'Gigabytes/Second',
-                        'Terabytes/Second',
-                        'Bits/Second',
-                        'Kilobits/Second',
-                        'Megabits/Second',
-                        'Gigabits/Second',
-                        'Terabits/Second',
-                        'Count/Second',
-                        'None',
-                    ),
                 ),
                 'EvaluationPeriods' => array(
                     'required' => true,
@@ -810,12 +697,6 @@ return array (
                     'required' => true,
                     'type' => 'string',
                     'location' => 'aws.query',
-                    'enum' => array(
-                        'GreaterThanOrEqualToThreshold',
-                        'GreaterThanThreshold',
-                        'LessThanThreshold',
-                        'LessThanOrEqualToThreshold',
-                    ),
                 ),
             ),
             'errorResponses' => array(
@@ -921,35 +802,6 @@ return array (
                             ),
                             'Unit' => array(
                                 'type' => 'string',
-                                'enum' => array(
-                                    'Seconds',
-                                    'Microseconds',
-                                    'Milliseconds',
-                                    'Bytes',
-                                    'Kilobytes',
-                                    'Megabytes',
-                                    'Gigabytes',
-                                    'Terabytes',
-                                    'Bits',
-                                    'Kilobits',
-                                    'Megabits',
-                                    'Gigabits',
-                                    'Terabits',
-                                    'Percent',
-                                    'Count',
-                                    'Bytes/Second',
-                                    'Kilobytes/Second',
-                                    'Megabytes/Second',
-                                    'Gigabytes/Second',
-                                    'Terabytes/Second',
-                                    'Bits/Second',
-                                    'Kilobits/Second',
-                                    'Megabits/Second',
-                                    'Gigabits/Second',
-                                    'Terabits/Second',
-                                    'Count/Second',
-                                    'None',
-                                ),
                             ),
                         ),
                     ),
@@ -1002,11 +854,6 @@ return array (
                     'required' => true,
                     'type' => 'string',
                     'location' => 'aws.query',
-                    'enum' => array(
-                        'OK',
-                        'ALARM',
-                        'INSUFFICIENT_DATA',
-                    ),
                 ),
                 'StateReason' => array(
                     'required' => true,
