@@ -63,6 +63,11 @@ return array (
             'https' => true,
             'hostname' => 'elasticloadbalancing.sa-east-1.amazonaws.com',
         ),
+        'cn-north-1' => array(
+            'http' => true,
+            'https' => true,
+            'hostname' => 'elasticloadbalancing.cn-north-1.amazonaws.com.cn',
+        ),
         'us-gov-west-1' => array(
             'http' => true,
             'https' => true,
