@@ -22,6 +22,7 @@ use Aws\S3\Exception\NoSuchKeyException;
 use Aws\S3\Iterator\ListObjectsIterator;
 use Guzzle\Http\EntityBody;
 use Guzzle\Http\CachingEntityBody;
+use Guzzle\Http\Mimetypes;
 use Guzzle\Stream\PhpStreamRequestFactory;
 use Guzzle\Service\Command\CommandInterface;
 
@@ -209,6 +210,14 @@ class StreamWrapper
         $params = $this->params;
         $params['Body'] = $this->body;
 
+        // Attempt to guess the ContentType of the upload based on the
+        // file extension of the key
+        if (!isset($params['ContentType']) &&
+            ($type = Mimetypes::getInstance()->fromFilename($params['Key']))
+        ) {
+            $params['ContentType'] = $type;
+        }
+
         try {
             self::$client->putObject($params);
             return true;
@@ -313,25 +322,30 @@ class StreamWrapper
 
         $parts = $this->getParams($path);
 
-        // Stat a bucket or just s3://
-        if (!$parts['Key'] && (!$parts['Bucket'] || self::$client->doesBucketExist($parts['Bucket']))) {
-            return $this->formatUrlStat($path);
-        }
-
-        // You must pass either a bucket or a bucket + key
         if (!$parts['Key']) {
-            return $this->triggerError("File or directory not found: {$path}", $flags);
+            // Stat "directories": buckets, or "s3://"
+            if (!$parts['Bucket'] || self::$client->doesBucketExist($parts['Bucket'])) {
+                return $this->formatUrlStat($path);
+            } else {
+                return $this->triggerError("File or directory not found: {$path}", $flags);
+            }
         }
 
         try {
             try {
-                // Attempt to stat and cache regular object
-                return $this->formatUrlStat(self::$client->headObject($parts)->toArray());
+                $result = self::$client->headObject($parts)->toArray();
+                if (substr($parts['Key'], -1, 1) == '/' && $result['ContentLength'] == 0) {
+                    // Return as if it is a bucket to account for console bucket objects (e.g., zero-byte object "foo/")
+                    return $this->formatUrlStat($path);
+                } else {
+                    // Attempt to stat and cache regular object
+                    return $this->formatUrlStat($result);
+                }
             } catch (NoSuchKeyException $e) {
                 // Maybe this isn't an actual key, but a prefix. Do a prefix listing of objects to determine.
                 $result = self::$client->listObjects(array(
                     'Bucket'  => $parts['Bucket'],
-                    'Prefix'  => $parts['Key'],
+                    'Prefix'  => rtrim($parts['Key'], '/') . '/',
                     'MaxKeys' => 1
                 ));
                 if (!$result['Contents'] && !$result['CommonPrefixes']) {
